"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DateTimePicker = exports.DateTimeTabs = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _practicalReactComponentsIcons = require("practical-react-components-icons");

var _designparams = require("../designparams");

var _DateTimeInformation = require("./DateTimeInformation");

var _TimePicker = require("./TimePicker");

var _DatePicker = require("./DatePicker");

var _Typography = require("../Typography");

var _Modal = require("../Modal");

var _Button = require("../Button");

var _ToggleButtonGroup = require("../ToggleButtonGroup");

var _Paper = require("../Paper");

var _Icon = require("../Icon");

var _excluded = ["open", "date", "lang", "header", "onCancelAction", "onSaveAction", "hour12", "initialTab", "hour12MeridiemLabels"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var DateTimeTabs;
exports.DateTimeTabs = DateTimeTabs;

(function (DateTimeTabs) {
  DateTimeTabs["TwentyFour"] = "24";
  DateTimeTabs["AMPM"] = "AM/PM";
  DateTimeTabs["Min"] = "Min";
  DateTimeTabs["Date"] = "Date";
})(DateTimeTabs || (exports.DateTimeTabs = DateTimeTabs = {}));

var TitleContainer = _styledComponents.default.div.withConfig({
  displayName: "DateTimePicker__TitleContainer",
  componentId: "ypqtka-0"
})(["color:", ";fill:", ";"], _ref => {
  var {
    theme
  } = _ref;
  return theme.color.text04();
}, _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.color.text04();
});

var InformationContainer = _styledComponents.default.div.withConfig({
  displayName: "DateTimePicker__InformationContainer",
  componentId: "ypqtka-1"
})(["padding:", " ", ";border-bottom:1px solid ", ";"], _designparams.spacing.large, _designparams.spacing.extraLarge, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.color.background01();
});

var ContentContainer = _styledComponents.default.div.withConfig({
  displayName: "DateTimePicker__ContentContainer",
  componentId: "ypqtka-2"
})(["display:flex;flex-direction:column;justify-content:flex-start;height:100%;padding:", " ", ";"], _designparams.spacing.large, _designparams.spacing.extraLarge);

var FooterContainer = _styledComponents.default.div.withConfig({
  displayName: "DateTimePicker__FooterContainer",
  componentId: "ypqtka-3"
})(["padding:0 ", " ", ";display:flex;flex-direction:row-reverse;>:last-child{margin-right:", ";}"], _designparams.spacing.large, _designparams.spacing.extraLarge, _designparams.spacing.medium);

var StyledPaper = (0, _styledComponents.default)(_Paper.Paper).withConfig({
  displayName: "DateTimePicker__StyledPaper",
  componentId: "ypqtka-4"
})(["width:360px;height:688px;display:flex;flex-direction:column;justify-content:space-between;"]);

/**
 * DateTimePicker
 *
 * Dialog that can be used for date, time and time zone settings.
 */
var DateTimePicker = _ref4 => {
  var {
    open,
    date,
    lang = 'en',
    header,
    onCancelAction,
    onSaveAction,
    hour12,
    initialTab,
    hour12MeridiemLabels = {
      am: 'AM',
      pm: 'PM'
    }
  } = _ref4,
      modalProps = _objectWithoutProperties(_ref4, _excluded);

  var [dateTime, setDateTime] = (0, _react.useState)(new Date(date));
  (0, _react.useEffect)(() => setDateTime(new Date(date)), [date]);
  var [selectedTab, setSelectedTab] = (0, _react.useState)(() => {
    if (initialTab !== undefined && initialTab in DateTimeTabs) {
      return initialTab;
    }

    return hour12 ? DateTimeTabs.AMPM : DateTimeTabs.TwentyFour;
  });
  var onSaveClick = (0, _react.useCallback)(() => onSaveAction.onClick(dateTime.toISOString()), [dateTime, onSaveAction]);
  var onCancelClick = (0, _react.useCallback)(() => {
    onCancelAction.onClick();
    setDateTime(new Date(date));
  }, [date, onCancelAction]);
  var toggleButtonOptions = (0, _react.useMemo)(() => [{
    id: hour12 ? DateTimeTabs.AMPM : DateTimeTabs.TwentyFour,
    content: /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
      icon: _practicalReactComponentsIcons.ClockHourIcon
    })
  }, {
    id: DateTimeTabs.Min,
    content: /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
      icon: _practicalReactComponentsIcons.ClockMinuteIcon
    })
  }, {
    id: DateTimeTabs.Date,
    content: /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
      icon: _practicalReactComponentsIcons.SystemDatetimeIcon
    })
  }], [hour12]);
  return /*#__PURE__*/_react.default.createElement(_Modal.Modal, _extends({
    open: open,
    onClose: onCancelClick,
    verticallyCenter: true
  }, modalProps), /*#__PURE__*/_react.default.createElement(StyledPaper, null, /*#__PURE__*/_react.default.createElement(InformationContainer, null, /*#__PURE__*/_react.default.createElement(TitleContainer, null, /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
    variant: "dialog-heading"
  }, header))), /*#__PURE__*/_react.default.createElement(InformationContainer, null, /*#__PURE__*/_react.default.createElement(_DateTimeInformation.DateTimeInformation, {
    dateTime: dateTime,
    lang: lang,
    hour12: hour12
  })), /*#__PURE__*/_react.default.createElement(ContentContainer, null, /*#__PURE__*/_react.default.createElement(_ToggleButtonGroup.ToggleButtonGroup, {
    onChange: setSelectedTab,
    options: toggleButtonOptions,
    values: [selectedTab]
  }), selectedTab === DateTimeTabs.TwentyFour ? /*#__PURE__*/_react.default.createElement(_TimePicker.TimePickerTwentyFour, {
    onChange: setDateTime,
    date: dateTime
  }) : null, selectedTab === DateTimeTabs.Min ? /*#__PURE__*/_react.default.createElement(_TimePicker.MinutePicker, {
    onChange: setDateTime,
    date: dateTime
  }) : null, selectedTab === DateTimeTabs.AMPM ? /*#__PURE__*/_react.default.createElement(_TimePicker.TimePickerAMPM, {
    onChange: setDateTime,
    date: dateTime,
    hour12MeridiemLabels: hour12MeridiemLabels
  }) : null, selectedTab === DateTimeTabs.Date ? /*#__PURE__*/_react.default.createElement(_DatePicker.DatePicker, {
    lang: lang,
    onChange: setDateTime,
    date: dateTime
  }) : null), /*#__PURE__*/_react.default.createElement(FooterContainer, null, /*#__PURE__*/_react.default.createElement(_Button.Button, {
    onClick: onSaveClick,
    label: onSaveAction.label,
    variant: "primary"
  }), /*#__PURE__*/_react.default.createElement(_Button.Button, {
    onClick: onCancelClick,
    label: onCancelAction.label,
    variant: "secondary"
  }))));
};

exports.DateTimePicker = DateTimePicker;