/**
 * BaseDialog
 *
 * The BaseDialog component provides a structured Modal, containing
 * a fixed header and footer section, and a scrollable body section
 * that can expand/contract based on the content size.
 *
 * The header/footer are styled depending on the scroll state to
 * indicated start/end of scrolling.
 *
 * By filling the header/footer and content, you can build up more
 * specific dialogs. All dialogs should follow this structure.
 */
import React, { ReactNode } from 'react';
import { ModalProps } from '../Modal';
export declare type DialogWidth = 'normal' | 'settings-panel' | 'large-settings-panel';
interface BaseDialogContentProps {
    /**
     * The width of the dialog, one of `'normal'`, `'settings-panel'` or
     * `'large-settings-panel'`.
     *
     * Default: `'normal'`
     */
    readonly width?: DialogWidth;
    /**
     * React element that will go into the top of the dialog.
     */
    readonly header?: ReactNode;
    /**
     * React element that will go into the bottom of the dialog.
     */
    readonly footer: ReactNode;
}
export declare type BaseDialogProps = BaseDialogContentProps & ModalProps;
export declare const BaseDialog: React.FC<BaseDialogProps>;
export {};
