"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ExpandableListItem = exports.ExpandableListContainer = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _Transition = require("../Transition");

var _ListItemContainer = require("./ListItemContainer");

var _excluded = ["item", "expandedItems", "setExpandedItems", "isNestedItem"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var ExpandableListContainer = _styledComponents.default.div.withConfig({
  displayName: "ExpandableListItem__ExpandableListContainer",
  componentId: "p3zf2x-0"
})(["display:inline-flex;flex-direction:column;width:100%;overflow:hidden;"]);

exports.ExpandableListContainer = ExpandableListContainer;

var ItemWrapper = _styledComponents.default.div.withConfig({
  displayName: "ExpandableListItem__ItemWrapper",
  componentId: "p3zf2x-1"
})(["background-color:", ";"], _ref => {
  var {
    theme
  } = _ref;
  return theme.color.background00();
});

/**
 * ExpandableListItem
 *
 * The ExpandableListItem component (recursive component) wraps and builds the item in the list.
 * It may contain an array of nested items, each of which will be wrapped in this
 * component as well.
 *
 */
var ExpandableListItem = _ref2 => {
  var {
    item,
    expandedItems,
    setExpandedItems,
    isNestedItem
  } = _ref2,
      props = _objectWithoutProperties(_ref2, _excluded);

  var {
    id,
    label,
    icon,
    selected = false,
    onClick,
    items
  } = item;
  var onChildClick = (0, _react.useCallback)(() => (itemId => {
    var nextExpandedItems = expandedItems.includes(itemId) ? expandedItems.filter(i => i !== itemId) : [...expandedItems, id];
    setExpandedItems(nextExpandedItems);
  })(id), [expandedItems, id, setExpandedItems]);
  var hasChildren = items !== undefined;
  var onItemClick = hasChildren ? onChildClick : onClick;
  var expanded = expandedItems.includes(id);
  var childSelected = items !== undefined ? Boolean(items.find(_ref3 => {
    var {
      selected: subSelected = false
    } = _ref3;
    return subSelected;
  })) : false;
  return /*#__PURE__*/_react.default.createElement(ItemWrapper, _extends({
    key: id
  }, props), /*#__PURE__*/_react.default.createElement(_ListItemContainer.ListItemContainer, {
    selected: selected,
    isNestedItem: isNestedItem,
    hasChildren: hasChildren,
    expanded: expanded,
    childSelected: childSelected,
    onClick: onItemClick,
    icon: icon,
    label: label
  }), items !== undefined ? /*#__PURE__*/_react.default.createElement(_Transition.FoldTransition, {
    expanded: expanded
  }, /*#__PURE__*/_react.default.createElement(ExpandableListContainer, null, items.map(i => /*#__PURE__*/_react.default.createElement(ExpandableListItem, {
    key: i.id,
    item: i,
    expandedItems: expandedItems,
    setExpandedItems: setExpandedItems,
    isNestedItem: true
  })))) : null);
};

exports.ExpandableListItem = ExpandableListItem;