"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.opacity = exports.iconSize = exports.componentSize = exports.shape = exports.spacing = void 0;

/*
 * Design parameters
 *
 * Parametrize different design properties of the UI components.
 * These are _not_ part of the theme (which only has font/color),
 * as components are built to conform to these properties.
 */

/**
 * Spacing
 * @extraSmall '2px',
 * @small '4px',
 * @medium '8px',
 * @large '16px',
 * @extraLarge '24px',
 * @huge '32px',
 */
var spacing = {
  extraSmall: '2px',
  small: '4px',
  medium: '8px',
  large: '16px',
  extraLarge: '24px',
  huge: '32px'
};
exports.spacing = spacing;

/**
 * Basic shapes
 */
var shape = {
  radius: {
    circle: '50%',
    small: '2px',
    medium: '4px',
    large: '8px'
  }
};
exports.shape = shape;

/**
 * Component size
 * @mini '24px',
 * @small '32px',
 * @medium '40px',
 * @large '48px',
 * @extraLarge '56px',
 */
var componentSize = {
  mini: '24px',
  small: '32px',
  medium: '40px',
  large: '48px',
  extraLarge: '56px'
};
exports.componentSize = componentSize;

/**
 * Icon size
 * @small '16px',
 * @medium '24px',
 * @large '40px',
 * @extraLarge '80px',
 */
var iconSize = {
  small: '16px',
  medium: '24px',
  large: '40px',
  extraLarge: '80px'
};
exports.iconSize = iconSize;

/**
 * Opacities
 */
var opacity = {
  16: 0.16,
  24: 0.24,
  40: 0.4,
  48: 0.48
};
exports.opacity = opacity;